<?
    /*
     * File: bugs.php
     *
     * Description:
     *     This file contains utility functions for working with bugs
     *
     * Creator: Chris Ryan <chris@greatbridge.com>
     * Created: 10/05/2000
     *
     * Change Log:
     *     Chris Ryan <chris@greatbridge.com> 10/05/2000
     *         - Initial file creation
     *     Chris Ryan <chris@greatbridge.com> 10/23/2000
     *         - Added calls to pg_freeresult after completion
     *           of each query.
     */

    # this is the cat_id of the record in the database for the
    # default status of bugs
    $BUG_DEFAULT_STATUS = 46;

    /*
     * Function: getBugStatusList();
     *
     * Description: returns an array of key:value pairs of valid bug statuses
     */
     function getBugStatusList() {
         global $conn;
         $query = "  select cat_id, cat_name ".
                  "    from category ".
                  "   where type_id = 3 ".
                  "order by cat_id ";
         $res   = pg_exec($conn,$query);
         $r = 0;
         while($row = @pg_fetch_array($res,$r++)) {
             $list[$row["cat_id"]] = $row["cat_name"];
         }
         pg_freeresult($res);
         return $list;
     }

    /*
     * Function: getBugSeverityList();
     *
     * Description: returns an array of key:value pairs of valid bug severities
     */
     function getBugSeverityList() {
         global $conn;
         $query = "  select cat_id, cat_name ".
                  "    from category ".
                  "   where type_id = 5 ".
                  "order by cat_id ";
         $res   = pg_exec($conn,$query);
         $r = 0;
         while($row = @pg_fetch_array($res,$r++)) {
             $list[$row["cat_id"]] = $row["cat_name"];
         }
         pg_freeresult($res);
         return $list;
     }

    /*
     * Function: getBugClassList();
     *
     * Description: returns an array of key:value pairs of valid bug classes
     */
     function getBugClassList() {
         global $conn;
         $query = "  select cat_id, cat_name ".
                  "    from category ".
                  "   where type_id = 6 ".
                  "order by cat_id ";
         $res   = pg_exec($conn,$query);
         $r = 0;
         while($row = @pg_fetch_array($res,$r++)) {
             $list[$row["cat_id"]] = $row["cat_name"];
         }
         pg_freeresult($res);
         return $list;
     }

     /*
      * Function: mailBug($bug_id, $send_to, $header_tag, $comments)
      *
      * Description: mails a Bug report to the address specified with the
      *              additional header_tag on the email title and the
      *              comments before the bug report.
      */
     function mailBug($bug_id, $send_to, $header_tag, $comments) {
         global $conn;
         global $HTTP_HOST;
         $query = "select bug.title, c1.cat_name as class_id, bug.priority, ".
                  "       c2.cat_name as severity_id, ".
                  "       c3.cat_name as status_id, description, version, ".
                  "       os, os_version, ".
                  "       platform, task_id, created_by, email, ".
                  "       environment, date_created, project_id ".
                  "  from bug, category c1, category c2, category c3 ".
                  " where bug_id = $bug_id ".
                  "   and c1.cat_id = bug.class_id ".
                  "   and c2.cat_id = bug.severity_id ".
                  "   and c3.cat_id = bug.status_id ";
         $res   = @pg_exec($conn,$query);
         if(!empty($res) && pg_numrows($res) > 0) {
             $bug = pg_fetch_array($res,0);
             $project_name = getProjectName($bug["project_id"]);
             if(empty($bug["created_by"])) {
                 $created_by = $bug["email"];
                 $creator_email = $created_by;
             } else {
                 $created_by = getMemberName($bug["created_by"]);
                 $creator_email = getMemberEmail($bug["created_by"]);
             }

             $bug_comments = "";
             $query = "  select comment, created_by, email, date_created ".
                      "    from bug_comment ".
                      "   where bug_id = $bug_id ".
                      "order by date_created ";
             $res   = @pg_exec($conn,$query);
             $r = 0;
             while($row = @pg_fetch_array($res,$r++)) {
                 $bug_comments .= "\n";
                 $bug_comments .= (empty($row["created_by"])?
                                   $row["email"]:
                                   getMemberName($row["created_by"]));
                 $bug_comments .= " : ";
                 $bug_comments .= date("m/d/Y",strtotime($row["date_created"]));
                 $bug_comments .= "\n\t" . $row["comment"] . "\n";
             }

             mail($send_to,"BUG: ${bug["title"]} (ID: $bug_id) $header_tag","$comments

Title: ${bug["title"]}
Bug Type: ${bug["class_id"]}
Severity: ${bug["severity_id"]}
Software Version: ${bug["version"]}
Environment: ${bug["environment"]}
Created By: $created_by
Description: ${bug["description"]}
Status: ${bug["status_id"]}

$bug_comments

http://www.$HTTP_HOST/project/$project_name/bugs/bugupdate.php?$bug_id
","From: $creator_email");
         }
     }

 ?>
